@@ -1,5 +1,6 @@
 """Base time conversion functions"""
 from datetime import datetime as _datetime
+from io import StringIO as _StringIO
 
 import numpy as _np
 import pandas as _pd
@@ -126,31 +127,24 @@ def gpswkD2dt(gpswkD):
     return dt_64.astype(_datetime)
 
 
-def yydoysec2datetime(snxdate: _np.ndarray or _pd.Series, recenter: bool = True, as_j2000: bool = True) -> _np.ndarray:
-
-    """Converts snx YY.DOY.SSSSS object Series to datetime64.
-    recenter overrirdes day seconds value to midday
+def yydoysec2datetime(
+    arr: _np.ndarray or _pd.Series, recenter: bool = True, as_j2000: bool = True, delimiter: str = ":"
+) -> _np.ndarray:
+    """Converts snx YY:DOY:SSSSS [snx] or YYYY:DOY:SSSSS [bsx/bia] object Series/ndarray to datetime64.
+    recenter overrides day seconds value to midday
     as_j2000 outputs int seconds after 2000-01-01 12:00:00, datetime64 otherwise"""
-    if not isinstance(snxdate, _np.ndarray):
-        snxdate = snxdate.values  # if Series to ndarray
+    dt = _pd.read_csv(_StringIO("\n".join(arr)), sep=delimiter, header=None, dtype=int).values
 
-    snxdate = list(_np.char.split(a=snxdate.astype("<U12"), sep=":"))
-    snxdate = _np.asarray(snxdate, dtype=_np.int_)
+    yy_mask = dt[:, 0] < 100
+    if yy_mask.sum() != 0:
+        # convert two-digit year YY to YYYY
+        dt[yy_mask, 0] += 2000 - (100 * (dt[yy_mask, 0] > 50))
 
-    delta_years = snxdate[:, 0]
-    day_of_year = snxdate[:, 1]
-    secs_day = snxdate[:, 2]
-
-    delta_years -= 100 * (delta_years > 50)
-    years = _np.datetime64("2000-01-01").astype("datetime64[Y]") + delta_years
-
-    date = years.astype("datetime64[D]") + (day_of_year - 1)  # as years start with day no. 1
-    time = _gn_const.SEC_IN_DAY // 2 if recenter else secs_day
-    datetime = date.astype("datetime64[s]") + time
-
-    if as_j2000:
-        return datetime2j2000(datetime)
-    return datetime
+    years_as_sec = (dt[:, 0] - 1970).astype("datetime64[Y]").astype("datetime64[s]")
+    days_as_sec = dt[:, 1] * _gn_const.SEC_IN_DAY
+    seconds = dt[:, 2] if not recenter else _gn_const.SEC_IN_DAY // 2
+    datetime64 = years_as_sec + days_as_sec + seconds
+    return datetime2j2000(datetime64) if as_j2000 else datetime64
 
 
 def datetime2yydoysec(datetime):
@@ -267,3 +261,16 @@ def j20002rnxdt(j2000secs: _np.ndarray) -> _np.ndarray:
     time_m = _pd.Series((minute - hour).astype(int).astype(str)).str.rjust(3).values
     time_s = (_pd.Series((datetime - minute)).view(int) / 1e9).apply("{:.8f}\n".format).str.rjust(13).values
     return date_y + date_m + date_d + time_h + time_m + time_s
+
+
+def strdatetime2datetime(dt_arr, as_j2000=True):
+    """ conversion of IONEX map headers ndarray Y M D h m s to datetime64"""
+    datetime = (
+        dt_arr[:, 0].astype("datetime64[Y]") # no 1970 origin issue when from str
+        + (dt_arr[:, 1].astype("timedelta64[M]") - 1) # datetime year starts with 01 months (e.g. 2019-01) hence 1 must be subtracted from months
+        + (dt_arr[:, 2].astype("timedelta64[D]") - 1) # same with days - starts with 01, e.g., 2019-01-01
+        + (dt_arr[:, 3].astype("timedelta64[h]"))
+        + (dt_arr[:, 4].astype("timedelta64[m]"))
+        + (dt_arr[:, 5].astype("timedelta64[s]"))
+    )
+    return datetime2j2000(datetime) if as_j2000 else datetime
