@@ -79,34 +79,36 @@ def _diff2msg(diff, tol=None, dt_as_gpsweek=False):
         + "%)"
     )
 
-    msg["DIFF/MIN_DIFF"] = (
-        diff_min.round(4).astype(str)
-        + ("±" + std_min.round(4).astype(str).str.ljust(6, fillchar="0") if from_valvar else "")
-        + " @"
-        + (
+    msg["DIFF/MIN_DIFF"] = diff_min.round(4).astype(str) + (
+        "±" + std_min.round(4).astype(str).str.ljust(6, fillchar="0") if from_valvar else ""
+    )
+    if dt_as_gpsweek is not None:
+        datetime = (
             (_gn_datetime.datetime2gpsweeksec(idx_min.values, as_decimal=True) + 1e-7).astype("<U11")
             if dt_as_gpsweek
             else _gn_datetime.j20002datetime(idx_min.values).astype(str)
         )
-    )
+        msg["DIFF/MIN_DIFF"] += "@" + datetime.astype(object)
 
     if (diff_count[mask] > 1).sum() > 0:
-        msg["MAX_DIFF"] = (
-            diff_max.round(4).astype(str).str.rjust(7)
-            + ("±" + std_max.round(4).astype(str).str.ljust(6, fillchar="0") if from_valvar else "")
-            + " @"
-            + (
-                (_gn_datetime.datetime2gpsweeksec(idx_min.values, as_decimal=True) + 1e-7).astype("<U11")
+        msg["MAX_DIFF"] = diff_max.round(4).astype(str).str.rjust(7) + (
+            "±" + std_max.round(4).astype(str).str.ljust(6, fillchar="0") if from_valvar else ""
+        )
+        if dt_as_gpsweek is not None:
+            datetime = (
+                (_gn_datetime.datetime2gpsweeksec(idx_max.values, as_decimal=True) + 1e-7).astype("<U11")
                 if dt_as_gpsweek
-                else _gn_datetime.j20002datetime(idx_min.values).astype(str)
+                else _gn_datetime.j20002datetime(idx_max.values).astype(str)
             )
-        ) * (diff_count[mask] > 1)
+            msg["MAX_DIFF"] += "@" + datetime.astype(object)
 
         msg["MEAN_DIFF"] = (
             diff_over.mean(axis=0).round(4).astype(str)
             + "±"
             + diff_over.std(axis=0).round(4).astype(str).str.ljust(6, fillchar="0")
-        ) * (diff_count[mask] > 1)
+        )
+
+        msg.loc[diff_count[mask] <= 1, ["MAX_DIFF", "MEAN_DIFF"]] = ""
 
     return msg
 
@@ -118,12 +120,12 @@ def _compare_sv_states(diffstd, log_lvl, tol=None, plot=False):
         return 0
     if plot:
         # a standard scatter plot
-        _gn_plot.diff2plot(diff_sv.DIFF.PHASE_BIAS)
+        _gn_plot.diff2plot(diff_sv.DIFF.PHASE_BIAS, kind=None, title="PHASE BIAS DIFF")
 
         # a bar plot of mean values
         diffstd_mean = diff_sv.DIFF.PHASE_BIAS.mean(axis=0)
         diffstd_mean.index = diffstd_mean.index.to_series().astype(str)
-        _gn_plot.diff2plot(diffstd_mean, kind="bar")
+        _gn_plot.diff2plot(diffstd_mean, kind="bar", title="MEAN PHASE BIAS DIFF")
     bad_sv_states = _diff2msg(diff_sv, tol)
     if bad_sv_states is not None:
         _logging.log(
@@ -482,7 +484,7 @@ def sisre(
     alpha, beta = _np.vsplit(coeffs_df.values, indices_or_sections=2)
 
     sisre = _pd.DataFrame(
-        data=_np.sqrt((alpha * radial + clk_diff) ** 2 + (along ** 2 + cross ** 2) / beta),
+        data=_np.sqrt((alpha * radial + clk_diff) ** 2 + (along**2 + cross**2) / beta),
         index=rac_unstack.index,
         columns=rac_unstack.Radial.columns,
     )
@@ -557,6 +559,29 @@ def diffpodout(pod_out_a_path, pod_out_b_path, tol, log_lvl):
     return status
 
 
+def diffblq(blq_a_path, blq_b_path, tol, log_lvl):
+    if tol is None:
+        _logging.error(":diffutil STD [tol=None] is not supported for the blq files")
+        return 0
+
+    blq_a, blq_b = _gn_io.blq.read_blq(blq_a_path), _gn_io.blq.read_blq(blq_b_path)
+    status = 0
+    diff = blq_a - blq_b
+    bad_blq_vals = _diff2msg(diff.abs().T, 1e-4, dt_as_gpsweek=None)
+    if bad_blq_vals is not None:
+        _logging.log(
+            msg=f':diffutil found diff magnitudes above {tol:.1E} tolerance:\n{bad_blq_vals.to_string(justify="center")}\n',
+            level=log_lvl,
+        )
+        status = -1
+    else:
+        _logging.log(
+            msg=f":diffutil [OK] estimates diffs within  {tol:.1E} tolerance",
+            level=_logging.INFO,
+        )
+    return status
+
+
 def diffclk(clk_a_path, clk_b_path, tol, log_lvl):
     """Compares two clk files and provides a difference above atol if present. If sp3 orbits provided - does analysis using the SISRE values"""
     clk_a, clk_b = _gn_io.clk.read_clk(clk_a_path), _gn_io.clk.read_clk(clk_b_path)
