@@ -10,12 +10,21 @@ import pandas as _pd
 
 from .. import gn_const as _gn_const
 from .. import gn_datetime as _gn_datetime
+from .. import gn_aux as _gn_aux
 from .. import gn_io as _gn_io
 
-_RE_BLK_HEAD = _re.compile(rb"\+S\w+\/\w+(\s[LU]|)\s*(CORR|COVA|INFO|)[ ]*\n(?:\*[ ].+\n|)(?:\*\w.+\n|)")
+_RE_BLK_HEAD = _re.compile(rb"\+\w+\/\w+(\s[LU]|)\s*(CORR|COVA|INFO|)[ ]*\n(?:\*[ ].+\n|)(?:\*\w.+\n|)")
 _RE_STATISTICS = _re.compile(r"^[ ]([A-Z (-]+[A-Z)])[ ]+([\d+\.]+)", _re.MULTILINE)
 
 
+def snx_soln_converter(soln):
+    try:
+        return int(soln)
+    except ValueError:
+        _logging.debug(f"Converting non-integer solution marker ({soln}) to 0")
+        return 0
+
+
 def _get_valid_stypes(stypes):
     """Returns only stypes in allowed list
     Fastest if stypes size is small"""
@@ -168,7 +177,7 @@ def _get_snx_matrix(path_or_bytes, stypes=("APR", "EST"), verbose=True):
     return output, stypes_content
 
 
-def snxdf2xyzdf(snxdf, unstack=True):
+def snxdf2xyzdf(snxdf, unstack=True, keep_all_soln=None):
     types_mask = snxdf.TYPE.isin(
         [
             "STAX",
@@ -181,11 +190,23 @@ def snxdf2xyzdf(snxdf, unstack=True):
     ).values
     snxdf.drop(index=snxdf.index.values[~types_mask], inplace=True)
     snxdf["CODE_PT"] = snxdf.CODE.values + "_" + snxdf.PT.values.astype(object)
-    snx_df = snxdf.drop(columns=["CODE", "PT", "SOLN"]).set_index(["CODE_PT", "REF_EPOCH", "TYPE"])
+    snx_df = snxdf.drop(columns=["CODE", "PT"]).set_index(["CODE_PT", "REF_EPOCH", "TYPE"])
+    if keep_all_soln is None:
+        # Retain existing behaviour by (all solutions but no solution number) default
+        snx_df = snx_df.drop(columns=["SOLN"])
+    elif keep_all_soln:
+        # Keep all solutions but include SOLN as an index value, not a column to avoid reshape issues
+        snx_df = snx_df.set_index("SOLN", append=True)
+    else:
+        # Keep just 1 solution by sorting the high solutions to the toping, grouping things by all indices
+        # so we get a group for each site, time, pos/vel triplet, and then take the first element of that
+        # group, which will be the highest numbered solution thanks to the previous sort
+        snx_df = snx_df.sort_values("SOLN", ascending=False).groupby(level=snx_df.index.names).head(1)
+        snx_df = snx_df.drop(columns=["SOLN"])
     return snx_df.unstack(2) if unstack else snx_df
 
 
-def _get_snx_vector(path_or_bytes, stypes=("EST", "APR"), snx_format=True, verbose=True):
+def _get_snx_vector(path_or_bytes, stypes=("EST", "APR"), snx_format=True, keep_all_soln=None, verbose=True):
     """stypes = "APR","EST","NEQ"
     APRIORY, ESTIMATE, NORMAL_EQUATION
     """
@@ -223,15 +244,15 @@ def _get_snx_vector(path_or_bytes, stypes=("EST", "APR"), snx_format=True, verbo
             usecols=[0, 1, 2, 3, 4, 5, 8, 9],
             names=["INDEX", "TYPE", "CODE", "PT", "SOLN", "REF_EPOCH", "EST", "STD"],
             dtype={
-                0: int,
-                1: _gn_const.TYPE_CATEGORY,
-                2: object,
-                3: _gn_const.PT_CATEGORY,
-                4: "category",  # can not be int as may be '----'
-                5: object,
-                8: _np.float_,
-                9: _np.float_,
+                "INDEX": int,
+                "TYPE": _gn_const.TYPE_CATEGORY,
+                "CODE": object,
+                "PT": _gn_const.PT_CATEGORY,
+                "REF_EPOCH": object,
+                "EST": _np.float_,
+                "STD": _np.float_,
             },
+            converters={"SOLN": snx_soln_converter},
             index_col="INDEX",
         )
 
@@ -265,11 +286,7 @@ def _get_snx_vector(path_or_bytes, stypes=("EST", "APR"), snx_format=True, verbo
         output.append(vec_df)
         prev_idx += idx
     output = _pd.concat(output, axis=1)
-    if snx_format is None:
-        return output
-    if snx_format:
-        return snxdf2xyzdf(output, unstack=False)
-    return snxdf2xyzdf(output, unstack=True)
+    return snxdf2xyzdf(output, unstack=(not snx_format), keep_all_soln=keep_all_soln)
 
 
 def _matrix_raw2square(matrix_raw, stypes_form, n_elements=None):
@@ -399,28 +416,17 @@ def _get_snx_vector_gzchunks(filename, block_name="SOLUTION/ESTIMATE", size_look
 
 
 # SINEX ID BLOCK
-def degminsec2decdeg(series):
-    """Converts degrees/minutes/seconds to decimal degrees"""
-    _deg = series.str[:-8].values.astype(float)
-    _min = series.str[-8:-5].values.astype(float)
-    _sec = series.str[-5:].values.astype(float)
-    sign = _np.sign(_deg)
-    return _deg + sign * _min / 60 + sign * _sec / 3600
-
-
-def _get_snx_id(path, sites_only=False):
+def _get_snx_id(path):
     snx_bytes = _gn_io.common.path2bytes(path)
     site_id = _snx_extract_blk(snx_bytes=snx_bytes, blk_name="SITE/ID", remove_header=True)[0]
-    if sites_only:
-        return _np.char.strip(_np.asarray(site_id.splitlines()).astype("U5"))
 
     id_df = _pd.read_fwf(
         _BytesIO(site_id), header=None, colspecs=[(0, 5), (5, 8), (8, 18), (18, 20), (44, 55), (55, 68), (68, 76)]
     )
 
     id_df.columns = ["CODE", "PT", "DOMES", "T", "LON", "LAT", "H"]  # location may have non-unicode chars
-    id_df.LON = degminsec2decdeg(id_df.LON)
-    id_df.LAT = degminsec2decdeg(id_df.LAT)
+    id_df.LON = _gn_aux.degminsec2decdeg(id_df.LON)
+    id_df.LAT = _gn_aux.degminsec2decdeg(id_df.LAT)
     return id_df
 
 
@@ -502,7 +508,7 @@ def logllh2snxdms(llh):
     step2 = step1[step1_mask_stack].copy().values
     n_rows = step2.shape[0] // 2
 
-    dd = degminsec2decdeg(_pd.Series(step2[:, 0] + " " + step2[:, 1] + " " + step2[:, 2]))
+    dd = _gn_aux.degminsec2decdeg(_pd.Series(step2[:, 0] + " " + step2[:, 1] + " " + step2[:, 2]))
     hei = llh[step1_mask].HEI.values
     hei[hei == ""] = 9999
 
